﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;

using Infragistics.Controls.Charts;
using System.ComponentModel;

namespace xamDataChart_UseAndDimaicAddSeries
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        NumericYAxis volumeYAxis;
        NumericYAxis priceYAxis;
        CategoryXAxis sharedXAxis;

        ObservableCollection<Data> data1 = Data.GetData(10, 2, 50);

        public MainWindow()
        {
            InitializeComponent();

            volumeYAxis = new NumericYAxis();
            priceYAxis = new NumericYAxis();
            sharedXAxis = new CategoryXAxis();

            sharedXAxis.ItemsSource = data1;
            sharedXAxis.Label = "{Label}";

            // set location for the axes
            sharedXAxis.LabelSettings = new AxisLabelSettings { Location = AxisLabelsLocation.OutsideBottom };
            volumeYAxis.LabelSettings = new AxisLabelSettings { Location = AxisLabelsLocation.OutsideRight };
            priceYAxis.LabelSettings = new AxisLabelSettings { Location = AxisLabelsLocation.OutsideLeft };

            // add created axes to the chart
            this.xamDataChart1.Axes.Add(volumeYAxis);
            this.xamDataChart1.Axes.Add(priceYAxis);
            this.xamDataChart1.Axes.Add(sharedXAxis);

            // create a LineSeries
            LineSeries volumeSeries = new LineSeries();
            volumeSeries.ValueMemberPath = "Value";
            volumeSeries.Title = "Stock Volume";
            volumeSeries.XAxis = sharedXAxis;        // share x-axis
            volumeSeries.YAxis = volumeYAxis;
            volumeSeries.ItemsSource = data1;

            // add created series to the chart
            this.xamDataChart1.Series.Add(volumeSeries);
        }

        private void button1_Click(object sender, RoutedEventArgs e)
        {
            // Series
            SplineAreaSeries series = new SplineAreaSeries();
            series.ValueMemberPath = "Value";
            series.XAxis = sharedXAxis;
            series.YAxis = priceYAxis;
            series.ItemsSource = data1;
            this.xamDataChart1.Series.Add(series); 
        }

    }

    public class Data : INotifyPropertyChanged
    {

        private int value;
        private string label;

        public string Label
        {
            get { return label; }
            set
            {
                label = value;
                PropChanged("Label");
            }
        }

        public int Value
        {
            get { return value; }
            set
            {
                this.value = value;
                PropChanged("Value");
            }
        }

        public static ObservableCollection<Data> GetData(int points, int rangeStart, int rangeEnd)
        {
            ObservableCollection<Data> data = new ObservableCollection<Data>();
            Random r = new Random();
            for (int i = 0; i < points; i++)
            {
                data.Add(new Data
                {
                    Label = "Item " + i,
                    Value = r.Next(rangeStart, rangeEnd),
                });
            }

            return data;
        }

        public event PropertyChangedEventHandler PropertyChanged;

        public void PropChanged(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }
    }



}
